Graphical User Interface
========================

.. automodule:: hbat.gui.main_window
   :members:
   :undoc-members:
   :show-inheritance:

.. automodule:: hbat.gui.geometry_cutoffs_dialog
   :members:
   :undoc-members:
   :show-inheritance:

.. automodule:: hbat.gui.preset_manager_dialog
   :members:
   :undoc-members:
   :show-inheritance:

.. automodule:: hbat.gui.pdb_fixing_dialog
   :members:
   :undoc-members:
   :show-inheritance:

.. automodule:: hbat.gui.results_panel
   :members:
   :undoc-members:
   :show-inheritance:

.. automodule:: hbat.gui.chain_visualization
   :members:
   :undoc-members:
   :show-inheritance:

.. automodule:: hbat.gui.visualization_renderer
   :members:
   :undoc-members:
   :show-inheritance:

.. automodule:: hbat.gui.graphviz_renderer
   :members:
   :undoc-members:
   :show-inheritance:

.. automodule:: hbat.gui.matplotlib_renderer
   :members:
   :undoc-members:
   :show-inheritance:


.. automodule:: hbat.gui.export_manager
   :members:
   :undoc-members:
   :show-inheritance:


.. automodule:: hbat.gui.graphviz_preferences_dialog
   :members:
   :undoc-members:
   :show-inheritance: